# BEGIN COPYRIGHT BLOCK
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; version 2 of the License.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
#
# (C) 2007 Red Hat, Inc.
# All rights reserved.
# END COPYRIGHT BLOCK

###############################################################################
###                          D E F I N I T I O N S                          ###
###############################################################################

## Entity Definitions
%define base_entity       Red Hat
%define base_prefix       pki
%define base_ui_prefix    redhat

## Product Definitions
%define base_system       Certificate System
%define base_product      Certificate Authority User Interface
%define base_component    ca-ui
%define base_pki          %{base_entity} %{base_system}

## Package Header Definitions
%define base_name         %{base_ui_prefix}-%{base_prefix}-%{base_component}
%define base_version      8.1.0
%define base_release      10
%define base_phase        %{nil}
%define base_group        System Environment/Base
%define base_vendor       Red Hat, Inc.
%define base_license      GPLv2 with exceptions
%define base_packager     %{base_vendor} <http://bugzilla.redhat.com/bugzilla>
%define base_summary      %{base_pki} - %{base_product}
%define base_url          http://www.redhat.com/certificate_system

## Helper Definitions
%define pki_ca            %{base_entity} Certificate Authority
%define pki_drm           %{base_entity} Data Recovery Manager
%define pki_ds            %{base_entity} Directory Server
%define pki_ocsp          %{base_entity} Online Certificate Status Protocol Manager
%define pki_ra            %{base_entity} Registration Authority
%define pki_tks           %{base_entity} Token Key Service
%define pki_tps           %{base_entity} Token Processing System

## Don't build the debug packages
%define debug_package     %{nil}


##===================##
## Linux Definitions ##
##===================##
%ifos Linux
## A distribution model is required on certain Linux operating systems!
##
## check for a pre-defined distribution model
%define undefined_distro  %(test "%{dist}" = "" && echo 1 || echo 0)
%if %{undefined_distro}
%define is_fedora         %(test -e /etc/fedora-release && echo 1 || echo 0)
%if %{is_fedora}
## define a default distribution model on Fedora Linux
%define dist_prefix       .fc
%define dist_version      %(echo `rpm -qf --qf='%{VERSION}' /etc/fedora-release` | tr -d [A-Za-z])
%define dist              %{dist_prefix}%{dist_version}
%else
%define is_redhat         %(test -e /etc/redhat-release && echo 1 || echo 0)
%if %{is_redhat}
## define a default distribution model on Red Hat Linux
%define dist_prefix       .el
%define dist_version      %(echo `rpm -qf --qf='%{VERSION}' /etc/redhat-release` | tr -d [A-Za-z])
%define dist              %{dist_prefix}%{dist_version}
%endif
%endif
%endif
%endif



###############################################################################
###                       P A C K A G E   H E A D E R                       ###
###############################################################################

Name:           %{base_name}
Version:        %{base_version}
Release:        %{base_release}%{?base_phase}%{?dist}
Summary:        %{base_summary}
Vendor:         %{base_vendor}
URL:            %{base_url}
License:        %{base_license}
Packager:       %{base_packager}
Group:          %{base_group}


## Without AutoReqProv: no, rpmbuild finds all sorts of crazy
## dependencies that we don't care about, and refuses to install
AutoReqProv:    no

BuildArch:      noarch
BuildRoot:      %{_builddir}/%{base_name}-root


## NOTE:  This spec file may require a specific JDK, "gcc", and/or "gcc-c++"
##        packages as well as the "rpm" and "rpm-build" packages.
##
##        Technically, "ant" should not need to be in "BuildRequires" since
##        it is the Java equivalent of "make" (and/or "Autotools").
##
BuildRequires:  ant >= 1.6.5

## Without Requires something, rpmbuild will abort!
Requires:       bash >= 3.2
Provides:       %{base_prefix}-%{base_component}


## This package is non-relocatable!
#Prefix:

Source0:        %{base_name}-%{base_version}.tar.gz

## This package currently contains no patches!
#Patch0:


%description
%{base_pki} is an enterprise software system designed
to manage enterprise Public Key Infrastructure (PKI) deployments.

The %{base_entity} %{base_product} contains the graphical
user interface for the %{pki_ca}.



###############################################################################
###                  P R E P A R A T I O N   &   S E T U P                  ###
###############################################################################

## On Linux systems, prep and setup expect there to be a Source file
## in the /usr/src/redhat/SOURCES directory - it will be unpacked
## in the _builddir (not BuildRoot)
%prep


%setup -q


## This package currently contains no patches!
#%patch0
# patches



###############################################################################
###                        B U I L D   P R O C E S S                        ###
###############################################################################

%build
ant -Dspecfile=%{base_name}.spec



###############################################################################
###                 I N S T A L L A T I O N   P R O C E S S                 ###
###############################################################################

%install
cd dist/binary
unzip %{name}-%{version}.zip -d ${RPM_BUILD_ROOT}



###############################################################################
###                      C L E A N U P   P R O C E S S                      ###
###############################################################################

%clean
rm -rf ${RPM_BUILD_ROOT}



###############################################################################
###  P R E  &  P O S T   I N S T A L L / U N I N S T A L L   S C R I P T S  ###
###############################################################################

%pre
if [ "$1" -gt 1 ]; then
    backup_dir="%{_datadir}/%{base_prefix}/`rpm -q redhat-pki-ca-ui|cut -c12-`"
    if [ -e $backup_dir ]; then
        rm -rf $backup_dir
    fi

    cp -rf %{_datadir}/%{base_prefix}/%{base_component}  $backup_dir
fi

 
## This package currently contains no post-installation process!
#%post


## This package currently contains no pre-uninstallation process!
#%preun


## This package currently contains no post-uninstallation process!
#%postun



###############################################################################
###   I N V E N T O R Y   O F   F I L E S   A N D   D I R E C T O R I E S   ### 
###############################################################################

%files
%attr(-,root,root)     %{_datadir}/doc/%{base_name}-%{base_version}/*
%attr(-,root,root)     %{_datadir}/%{base_prefix}/*



###############################################################################
###                            C H A N G E L O G                            ###
###############################################################################

%changelog
* Mon May  4 2015 Matthew Harmsen <mharmsen@redhat.com> 8.1.0-10
- Bump release number to build RHCS 8.1.6

* Fri May  1 2015 Matthew Harmsen <mharmsen@redhat.com> 8.1.0-9
- Bump release number to build RHCS 8.1.6

* Thu Nov 3 2011 Andrew Wnuk <awnuk@redhat.com> 8.1.0-8
- Bugzilla Bug #747381 - After the migration (7.1->8.1) CA agent page displays
  admin cert request with authtime attribute twice

* Tue Sep 27 2011 Andrew Wnuk <awnuk@redhat.com> 8.1.0-7
- Bugzilla Bug #737423 - Ability to view migrated policy requests
  is very limited.

* Wed Jul 6 2011 Ade Lee <alee@redhat.com> 8.1.0-6
- Bugzilla Bug #706306 - scripts to allow in-place migration from 8.0 to 8.1

* Wed May 25 2011 Ade Lee <alee@redhat.com> 8.1.0-5
- Bugzilla Bug #704351 - remove help buttons in agent and ee UI in all
  subsystems (alee)

* Wed May 18 2011 Ade Lee <alee@redhat.com> 8.1.0-4
- Bugzilla Bug #706306 - added preinstall script to allow in-place upgrades
- Bugzilla Bug #704351 - remove help buttons in agent and ee UI in all subsystems

* Fri Apr 15 2011 Matthew Harmsen <mharmsen@redhat.com> 8.1.0-3
- Bugzilla Bug #695015 - Serial No. of a revoked certificate is not
  populated in the CA signedAudit messages (jmagne)
- Bugzilla Bug #694143 - CA Agent not returning specified request (awnuk)

* Thu Mar 24 2011 Matthew Harmsen <mharmsen@redhat.com> 8.1.0-2
- Bugzilla Bug #690646 - Update Build and Runtime Dependencies for RHCS 8.1

* Tue Jan 12 2010 Matthew Harmsen <mharmsen@redhat.com> 8.1.0-1
- Bump to version 8.1.0

* Tue Aug 18 2009 Ade Lee <alee@redhat.com> 8.0.1-1
- Update version for errata containing Bugzilla bugs 224688, 512828, 513450, 
  514093, 514094, 514270
* Thu Aug 6 2009 Andrew Wnuk <awnuk@redhat.com> 8.0.0-32
- Bugzilla Bug #514093 - UI ignores higher revocation reasons
* Thu Jul 30 2009 Andrew Wnuk <awnuk@redhat.com> 8.0.0-31
- Bugzilla Bug #514094 - enable ECC enrollment for FF through key constraints
* Mon Jul 13 2009 Matthew Harmsen <mharmsen@redhat.com> 8.0.0-30
- Bugzilla Bug #511136 -  Integrate EULA file into RHCS
- Release Candidate 4 build
* Wed Jul 8 2009 Kevin Wright <kwright@redhat.com> 8.0.0-29
- Bugzilla Bug #510352 -  Release Candidate 3 build
* Wed Jul 8 2009 Andrew Wnuk <awnuk@redhat.com> 8.0.0-28
- Bugzilla Bug #510165 - request search displays 'undefined' page size
* Mon Jul 6 2009 Andrew Wnuk <awnuk@redhat.com> 8.0.0-27
- Bugzilla Bug #492952 - handling 2K keys with MBCP
* Thu Jul 2 2009 Christina Fu <cfu@redhat.com> 8.0.0-26
- Bugzilla Bug #508332 - Clean up EE page certificate profiles
* Thu Jul 2 2009 Kevin Wright <kwright@redhat.com> 8.0.0-25
- Bugzilla Bug #509447 -  Release Candidate 2 build
* Thu Jun 25 2009 Kevin Wright <kwright@redhat.com> 8.0.0-24
- Bugzilla Bug #508179 -  Remove base_phase ".beta" tag
* Fri Jun 19 2009 Matthew Harmsen <mharmsen@redhat.com> 8.0.0-23
- Bugzilla Bug #506867 -  Provide custom error page for HTTP STATUS 500
* Mon Jun 15 2009 Matthew Harmsen <mharmsen@redhat.com> 8.0.0-22
- Bugzilla Bug #502908 -  Current page not found handling is a Cat 2 finding
  with the Tomcat STIG
* Fri Jun 12 2009 Andrew Wnuk <awnuk@redhat.com> 8.0.0-21
- Bugzilla Bug #502694 - adding random nonces
* Sat May 30 2009 Andrew Wnuk <awnuk@redhat.com> 8.0.0-20
- Bugzilla Bug #482935 - Adding search limits
* Wed May 20 2009 Andrew Wnuk <awnuk@redhat.com> 8.0.0-19
- Bugzilla Bug #491185 - added new revocation reasons to comply with RFC 5280
* Wed May 13 2009 Andrew Wnuk <awnuk@redhat.com> 8.0.0-18
- Bugzilla Bug #490551 - Use profile key constraints to control enrollment key sizes on IE
* Wed May 13 2009 Matthew Harmsen <mharmsen@redhat.com> 8.0.0-17
- Bugzilla Bug #500498 -  CA installation wizard doesn't install
  administrator cert into browser on Firefox 3
* Tue May 12 2009 Matthew Harmsen <mharmsen@redhat.com> 8.0.0-16
- Bugzilla Bug #500489 -  CA installation wizard doesn't prompt to
  download/install CA chain on Firefox 3
* Sun May 10 2009 Andrew Wnuk <awnuk@redhat.com> 8.0.0-15
- Bugzilla Bug #490551 - Use profile key constraints to control enrollment key sizes
* Tue May 5 2009 Matthew Harmsen <mharmsen@redhat.com> 8.0.0-14
- Bugzilla Bug #492735 -  Configuration wizard stores certain incorrect
  port values within TPS "CS.cfg" . . .
- Bugzilla Bug #495597 -  Unable to access Agent page using a configured
  CA/KRA containing an HSM

* Mon May 4 2009 Kevin Wright <kwright@redhat.com> 8.0.0-13
- Bugzilla Bug #499030 -  Beta 2 Release

* Fri Apr 10 2009 Ade Lee <alee@redhat.com> 8.0.0-12
- Bugzilla Bug #223353 - Values entered through web ui are not checked/escaped

* Tue Mar 31 2009 Andrew Wnuk <awnuk@redhat.com> 8.0.0-11
- Bugzilla Bug #490551 - 1024-bit and 2048-bit issuance configuration

* Mon Mar 30 2009 Andrew Wnuk <awnuk@redhat.com> 8.0.0-10
- Bugzilla Bug #492952 - better handling of enrollment objects for IE

* Fri Mar 27 2009 Andrew Wnuk <awnuk@redhat.com> 8.0.0-9
- Bugzilla Bug #224827 - new default cryptographic provider

* Fri Mar 27 2009 Matthew Harmsen <mharmsen@redhat.com> 8.0.0-8
- Bugzilla Bug #492502 -  Redefine "base_phase" from ".alpha" to ".beta"

* Tue Mar 24 2009 Matthew Harmsen <mharmsen@redhat.com> 8.0.0-7
- Bugzilla Bug #488388 -  copyright notices - remove from UI
- Bugzilla Bug #440543 -  CA's web-services page needs improvements

* Sat Feb 28 2009 Matthew Harmsen <mharmsen@redhat.com> 8.0.0-6
- Bugzilla Bug #487896 - Introduce optional 'base_phase' release tag to
  denote ".alpha", ".beta", etc.

* Fri Jan 30 2009 Ade Lee <alee@redhat.com> 8.0.0-5
- Bugzilla Bug #460582 - add UTF-8 support

* Sat Nov 29 2008 Matthew Harmsen <mharmsen@redhat.com> 8.0.0-4
- Aligned RHEL 5, RHEL 4, and Solaris 9 "base_release" numbers
- Bugzilla Bug #445402 - Changed "base_url" from
                         "http://www.redhat.com/software/rha/certificate" to
                         "http://www.redhat.com/certificate_system"

* Sat Nov 22 2008 Matthew Harmsen <mharmsen@redhat.com> 8.0.0-3
- Bugzilla Bug #472305 - "equality" tests in all spec files need to be fixed
- Bumped "java" and "java-devel" 1.4.2 and 1.5.0 dependencies to 1.6.0
- Changed "java-sdk" to "java-devel" for consistency

* Wed Oct 15 2008 Andrew Wnuk <awnuk@redhat.com> 8.0.0-2
- Fix for Bug 466064: Search filters built by CA servlets are not always correct
- Bugzilla bug #445436 - Bad search filter is reported by Revoke Certificates in Agent Interface

* Wed May 23 2007 Kevin McCarthy <kmccarth@redhat.com> 8.0.0-1
- Bump to version 8.0.0

* Thu May 17 2007 Thomas Kwan <nkwan@redhat.com> 1.0.0-1
- Initial Revision

